@@ -89,11 +89,13 @@ daybasis65 = create_fourier_basis(dayrange, nbasis);
 
 %  ----  set up the harmonic acceleration operator  -------
 
-Lbasis  = create_constant_basis(dayrange);  %  create a constant basis
-Lcoef   = [0,(2*pi/365)^2,0];    %  set up three coefficients
-wfd     = fd(Lcoef,Lbasis);      % define an FD object for weight functions
-wfdcell = fd2cell(wfd);          % convert the FD object to a cell object
-harmaccelLfd = Lfd(3, wfdcell);  %  define the operator object
+% Lbasis  = create_constant_basis(dayrange);  %  create a constant basis
+ Lcoef   = [0,(2*pi/365)^2,0];    %  set up three coefficients
+% wfd     = fd(Lcoef,Lbasis);      % define an FD object for weight functions
+% wfdcell = fd2cell(wfd);          % convert the FD object to a cell object
+% harmaccelLfd = Lfd(3, wfdcell);  %  define the operator object
+
+harmaccelLfd = vec2Lfd(Lcoef,dayrange);
 
 %  ---------  create fd objects for temp. and prec. ------------
 
@@ -403,6 +405,10 @@ pacindex = [12,17,18,30,31];
 conindex = [3,5,6,7,16,20,26,27,29,32,33,35];
 artindex = [10,11,21];
 
+% T-test for differences
+
+tperm_fd(tempfd(atlindex),tempfd(conindex));
+
 %  Set up a design matrix having a column for the grand mean, and
 %    a column for each climate zone effect. Add a dummy contraint
 %    observation
@@ -472,6 +478,12 @@ subplot(2,3,6)
 plot(yhatfdobj)
 title('Predicted values')
 
+% Try a cross-validation and permutation test
+
+sse_cv = fRegress_CV(tempfd, xfdcell, betacell,1:35);
+
+Fperm_fd(tempfd,xfdcell,betacell);
+
 %  compute mapping from data y to coefficients in c
 
 smallbasismat = eval_basis(daytime, smallbasis);
@@ -708,6 +720,11 @@ fRegressCell = fRegress(annualprec, xfdcell, betacell);
 betaestcell   = fRegressCell{4}; 
 annualprechat = fRegressCell{5};
 
+% Permutation F-test
+
+Fperm_fd(annualprec, xfdcell, betacell);
+
+
 %  constant term
 
 intercept = getcoef(getfd(betaestcell{1}));
